@@ -288,7 +288,6 @@ class Template(object):
 
         if elems and index < len(elems):
             elem = elems[index]
-            print('>>>>>>>>>>> hiding. elem parent is %s' % elem.parent)
             elem.parent.children.remove(elem)
 
     def repeat(self, rid, count, index=0):
@@ -340,7 +339,6 @@ class Template(object):
                 for child in replacement.root.children:
                     elem.parent.children.insert(current_pos, child)
                     child.parent = elem.parent
-                    print('>>>>>>>>>>>> GOT HERE set child parent %s to %s' % (child, elem.parent))
                     current_pos += 1
                 self.__merge_ids(self.__element_ids, replacement.__element_ids)
                 self.__merge_ids(self.__attrib_ids, replacement.__attrib_ids)
@@ -378,4 +376,4 @@ def get_template(name):
         except IOError:
             return None
 
-    return copy.deepcopy(templates[path])
\ No newline at end of file
+    return copy.deepcopy(templates[path])
